
# Slot: bidirectional


in addition to preconditions entailing postconditions, the postconditions entail the preconditions

URI: [linkml:bidirectional](https://w3id.org/linkml/bidirectional)


## Domain and Range

None &#8594;  <sub>0..1</sub> [Boolean](types/Boolean.md)

## Parents


## Children


## Used by

 * [ClassRule](ClassRule.md)

## Other properties

|  |  |  |
| --- | --- | --- |
| **Aliases:** | | iff |
|  | | if and only if |

